list/first_n.hpp

The list/first_n.hpp header defines macros for extracting a group of elements from the beginning of a list.

#### Usage

#include <boost/preprocessor/list/first_n.hpp>

#### Contents

- BOOST_PP_LIST_FIRST_N
- BOOST_PP_LIST_FIRST_N_D

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)